pbmc3k.sce.logcounts.RdLog-Normalized PBMC 3k: SingleCellExperiment Edition
pbmc3k.sce.logcountsA dgCMatrix with the
log-normalized PBMC 3k counts
There is not a raw, filtered matrix following a Bioconductor workflow
as scuttle does not filter the raw counts matrix in the same way that
SeuratObject::CreateSeuratObject() does
scuttle::perCellQCMetrics(),
scuttle::quickPerCellQC(),
scuttle::perCellQCFilters(),
scuttle::isOutlier()
Log-normalized matrices:
pbmc3k.seurat.norm